@@ -1,4 +1,4 @@
-/* @(#) Copyright (c), 1988, 2006 Insightful Corp.  All rights reserved. */
+
 /* @(#) $File: //depot/Research/ifultools/pkg/ifultools/inst/include/mat_umat.h $: $Revision: #1 $, $Date: 2008/03/21 $ */
 /* This is a self-documenting doc++ file. */
 
@@ -41,7 +41,6 @@ Macros for universal matrices
  * @see MATUNIV_NCOL
  */
 #define MATUNIV_NELEM(matrix)   (\
-        (!matrix) ? ((sint32)MUTIL_INVALID_LENGTH) :\
         ((matrix)->type == MUTIL_UINT8)    ?  ((matrix)->mat.u8mat.nelem) :\
         ((matrix)->type == MUTIL_SINT8)    ?  ((matrix)->mat.s8mat.nelem) :\
         ((matrix)->type == MUTIL_UINT16)   ?  ((matrix)->mat.u16mat.nelem) :\
@@ -68,7 +67,6 @@ Macros for universal matrices
  * @see MATUNIV_NELEM
  */
 #define MATUNIV_NROW(matrix)    (\
-        (!matrix) ? ((sint32) MUTIL_INVALID_LENGTH) :\
         ((matrix)->type == MUTIL_UINT8)    ?  ((matrix)->mat.u8mat.nrow) :\
         ((matrix)->type == MUTIL_SINT8)    ?  ((matrix)->mat.s8mat.nrow) :\
         ((matrix)->type == MUTIL_UINT16)   ?  ((matrix)->mat.u16mat.nrow) :\
@@ -95,7 +93,6 @@ Macros for universal matrices
  * @see MATUNIV_NELEM
  */
 #define MATUNIV_NCOL(matrix)    (\
-        (!matrix) ? ((sint32)MUTIL_INVALID_LENGTH) :\
         ((matrix)->type == MUTIL_UINT8)    ?  ((matrix)->mat.u8mat.ncol) :\
         ((matrix)->type == MUTIL_SINT8)    ?  ((matrix)->mat.s8mat.ncol) :\
         ((matrix)->type == MUTIL_UINT16)   ?  ((matrix)->mat.u16mat.ncol) :\
@@ -120,7 +117,6 @@ Macros for universal matrices
  * @see _univ_mat
  */
 #define MATUNIV_DATA(matrix)    (\
-     (!matrix) ? (void *)(matrix) :\
      ((matrix)->type==MUTIL_UINT8)    ?  (void *)((matrix)->mat.u8mat.data) :\
      ((matrix)->type==MUTIL_SINT8)    ?  (void *)((matrix)->mat.s8mat.data) :\
      ((matrix)->type==MUTIL_UINT16)   ?  (void *)((matrix)->mat.u16mat.data) :\
@@ -272,7 +268,8 @@ Macros for universal matrices
  */
 #define MATUNIV_CHECK_TYPE( mat1, mat2 )  \
         ( mat1 && mat2 && ( (mat1)->type == (mat2)->type) )
-
+#define MATUNIV_CHECK_TYPE2( mat1, mat2 )  \
+        ( mat2 && ( (mat1)->type == (mat2)->type) )
 
 /** Extract an element from a universal matrix given the data index.
  * Casts the value returned to double.
